MBR: fix pointer to partition table base
authorH. Peter Anvin <hpa@zytor.com>
Wed, 11 Jul 2007 22:40:44 +0000 (15:40 -0700)
committerH. Peter Anvin <hpa@zytor.com>
Wed, 11 Jul 2007 22:40:44 +0000 (15:40 -0700)
mbr/mbr.S

index 1093d87..cb8f6dc 100644 (file)
--- a/mbr/mbr.S
+++ b/mbr/mbr.S
@@ -232,11 +232,11 @@ scan_partition_table:
 
 /*
  * boot: invoke the actual bootstrap. (%si) points to the partition
*      table entry, and 22(%bp) has the partition table base.
  */
 boot:
        movl    8(%si), %eax
-       addl    22(%bp), %eax
+       addl    28(%bp), %eax
        movl    %eax, 8(%si)
        pushw   %si
        call    read_sector
@@ -232,11 +232,11 @@ scan_partition_table:
 /*
  * boot: invoke the actual bootstrap. (%si) points to the partition
- *      table entry, and 22(%bp) has the partition table base.
+ *      table entry, and 28(%bp) has the partition table base.
  */
 boot: